about summary refs log tree commit diff
path: root/src/libstd/map.rs
diff options
context:
space:
mode:
authorBrian Anderson <banderson@mozilla.com>2012-11-25 12:45:18 -0800
committerBrian Anderson <banderson@mozilla.com>2012-11-25 13:26:37 -0800
commit5c0206a1e4e5049a4a5d35ea6fee10cbd3f45aa0 (patch)
treecb3ab8eb672fab2de50e58dd640e7df8e087b347 /src/libstd/map.rs
parentff4075e553ccc5be73c05332f15ef46f761b0817 (diff)
downloadrust-5c0206a1e4e5049a4a5d35ea6fee10cbd3f45aa0.tar.gz
rust-5c0206a1e4e5049a4a5d35ea6fee10cbd3f45aa0.zip
Rename insert_with functions to update, update_with_key
Diffstat (limited to 'src/libstd/map.rs')
-rw-r--r--src/libstd/map.rs34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/libstd/map.rs b/src/libstd/map.rs
index 730b5275e1d..d68970679ad 100644
--- a/src/libstd/map.rs
+++ b/src/libstd/map.rs
@@ -35,16 +35,16 @@ pub trait Map<K:Eq IterBytes Hash Copy, V: Copy> {
      * If the map contains a value for the key, use the function
      * to set a new value.
      */
-    fn insert_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool;
+    fn update_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool;
 
     /**
      * Add a value to the map.
      *
      * If the map contains a value for the key, use the function
      * to set a new value.  (Like insert_with_key, but with a function
      * of only values.)
      */
-    fn insert_with(key: K, newval: V, ff: fn(V, V) -> V) -> bool;
+    fn update(key: K, newval: V, ff: fn(V, V) -> V) -> bool;
 
     /// Returns true if the map contains a value for the specified key
     pure fn contains_key(key: K) -> bool;
@@ -281,7 +281,7 @@ pub mod chained {
             }
         }
 
-        fn insert_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool {
+        fn update_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool {
 /*
             match self.find(key) {
                 None            => return self.insert(key, val),
@@ -330,8 +330,8 @@ pub mod chained {
             }
         }
 
-        fn insert_with(key: K, newval: V, ff: fn(V, V) -> V) -> bool {
-            return self.insert_with_key(key, newval, |_k, v, v1| ff(v,v1));
+        fn update(key: K, newval: V, ff: fn(V, V) -> V) -> bool {
+            return self.update_with_key(key, newval, |_k, v, v1| ff(v,v1));
         }
 
         pure fn get(k: K) -> V {
@@ -517,15 +517,15 @@ impl<K: Eq IterBytes Hash Copy, V: Copy> @Mut<LinearMap<K, V>>:
         }
     }
 
-    fn insert_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool {
+    fn update_with_key(key: K, newval: V, ff: fn(K, V, V) -> V) -> bool {
         match self.find(key) {
             None            => return self.insert(key, newval),
             Some(copy orig) => return self.insert(key, ff(key, orig, newval))
         }
     }
 
-    fn insert_with(key: K, newval: V, ff: fn(V, V) -> V) -> bool {
-        return self.insert_with_key(key, newval, |_k, v, v1| ff(v,v1));
+    fn update(key: K, newval: V, ff: fn(V, V) -> V) -> bool {
+        return self.update_with_key(key, newval, |_k, v, v1| ff(v,v1));
     }
 
     fn remove(key: K) -> bool {
@@ -833,7 +833,7 @@ mod tests {
     }
 
     #[test]
-    fn test_insert_with_key() {
+    fn test_update_with_key() {
         let map = map::HashMap::<~str, uint>();
 
         // given a new key, initialize it with this new count, given
@@ -848,11 +848,11 @@ mod tests {
 
         // count the number of several types of animal,
         // adding in groups as we go
-        map.insert_with(~"cat",      1, addMoreToCount_simple);
-        map.insert_with_key(~"mongoose", 1, addMoreToCount);
-        map.insert_with(~"cat",      7, addMoreToCount_simple);
-        map.insert_with_key(~"ferret",   3, addMoreToCount);
-        map.insert_with_key(~"cat",      2, addMoreToCount);
+        map.update(~"cat",      1, addMoreToCount_simple);
+        map.update_with_key(~"mongoose", 1, addMoreToCount);
+        map.update(~"cat",      7, addMoreToCount_simple);
+        map.update_with_key(~"ferret",   3, addMoreToCount);
+        map.update_with_key(~"cat",      2, addMoreToCount);
 
         // check the total counts
         assert 10 == option::get(map.find(~"cat"));
@@ -35,16 +35,16 @@ pub trait Map<K:Eq IterBytes Hash Copy, V: Copy> {
      * Add a value to the map.
      *
-     * If the map contains a value for the key, use the function
-     * to set a new value.  (Like insert_with_key, but with a function
-     * of only values.)
+     * If the map contains a value for the key, use the function to
+     * set a new value.  (Like `insert_or_update_with_key`, but with a
+     * function of only values.)
      */